package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.AdmOpInspectionReportMapper;
import com.ruoyi.ems.domain.AdmOpInspectionReport;
import com.ruoyi.ems.service.IAdmOpInspectionReportService;

/**
 * 巡检报告Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-29
 */
@Service
public class AdmOpInspectionReportServiceImpl implements IAdmOpInspectionReportService 
{
    @Autowired
    private AdmOpInspectionReportMapper admOpInspectionReportMapper;

    /**
     * 查询巡检报告
     * 
     * @param id 巡检报告主键
     * @return 巡检报告
     */
    @Override
    public AdmOpInspectionReport selectAdmOpInspectionReportById(Long id)
    {
        return admOpInspectionReportMapper.selectAdmOpInspectionReportById(id);
    }

    /**
     * 查询巡检报告列表
     * 
     * @param admOpInspectionReport 巡检报告
     * @return 巡检报告
     */
    @Override
    public List<AdmOpInspectionReport> selectAdmOpInspectionReportList(AdmOpInspectionReport admOpInspectionReport)
    {
        return admOpInspectionReportMapper.selectAdmOpInspectionReportList(admOpInspectionReport);
    }

    /**
     * 新增巡检报告
     * 
     * @param admOpInspectionReport 巡检报告
     * @return 结果
     */
    @Override
    public int insertAdmOpInspectionReport(AdmOpInspectionReport admOpInspectionReport)
    {
        return admOpInspectionReportMapper.insertAdmOpInspectionReport(admOpInspectionReport);
    }

    /**
     * 修改巡检报告
     * 
     * @param admOpInspectionReport 巡检报告
     * @return 结果
     */
    @Override
    public int updateAdmOpInspectionReport(AdmOpInspectionReport admOpInspectionReport)
    {
        return admOpInspectionReportMapper.updateAdmOpInspectionReport(admOpInspectionReport);
    }

    /**
     * 批量删除巡检报告
     * 
     * @param ids 需要删除的巡检报告主键
     * @return 结果
     */
    @Override
    public int deleteAdmOpInspectionReportByIds(Long[] ids)
    {
        return admOpInspectionReportMapper.deleteAdmOpInspectionReportByIds(ids);
    }

    /**
     * 删除巡检报告信息
     * 
     * @param id 巡检报告主键
     * @return 结果
     */
    @Override
    public int deleteAdmOpInspectionReportById(Long id)
    {
        return admOpInspectionReportMapper.deleteAdmOpInspectionReportById(id);
    }
}
